==> imp-doc-2.0.1.tar.gz: html/classIMP_1_1multifit_1_1AssemblyHeader.js <==
var classIMP_1_1multifit_1_1AssemblyHeader =
[
    [ "AssemblyHeader", "classIMP_1_1multifit_1_1AssemblyHeader.html#aae46c5cee094ac5d24152a4600584ba7", null ],
    [ "get_coarse_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a91052277ec7f86d23d91af1607c48904", null ],
    [ "get_coarse_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a7a19f4aee11a585737fb7ca9cefd68ef", null ],
    [ "get_dens_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a2ff85eef1cb89fdce9d6237de3de70f2", null ],
    [ "get_fine_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a0bfb7859edbd02ffd75ade1c513aa620", null ],
    [ "get_fine_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a662ee4d1263598c0257b0c79a979e641", null ],
    [ "get_origin", "classIMP_1_1multifit_1_1AssemblyHeader.html#a45aa5d7fab318a55bb2e5741573fb771", null ],
    [ "get_resolution", "classIMP_1_1multifit_1_1AssemblyHeader.html#a463328de5a75073c7bd74e08267800df", null ],
    [ "get_spacing", "classIMP_1_1multifit_1_1AssemblyHeader.html#ac65d23eac18ecef255822aa031c0db8b", null ],
    [ "get_threshold", "classIMP_1_1multifit_1_1AssemblyHeader.html#a8f0b4d1085cee5b37fae307242f2e3d2", null ],
    [ "set_coarse_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#aaa94d81eebc3c9f584ded58a4616e2cc", null ],
    [ "set_coarse_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#ae1a12a52e48c4055037c120717f8881c", null ],
    [ "set_dens_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a74474ef6f0421a2ec0d17980954bdcc6", null ],
    [ "set_fine_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#af1ace75aa2772da7cec62506bf16df01", null ],
    [ "set_fine_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a349d4c07f144d2617ea8f2b79280ea17", null ],
    [ "set_origin", "classIMP_1_1multifit_1_1AssemblyHeader.html#a149d094e7336923ac9fdbc50ed96b826", null ],
    [ "set_resolution", "classIMP_1_1multifit_1_1AssemblyHeader.html#a6461dff6026bbc54f261193059d80e59", null ],
    [ "set_spacing", "classIMP_1_1multifit_1_1AssemblyHeader.html#a3a9378689a931b70abf1672447a6d4ad", null ],
    [ "set_threshold", "classIMP_1_1multifit_1_1AssemblyHeader.html#a421838677fb527d765e2b4af3a081f1f", null ],
    [ "coarse_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#ad29c182851f7b0fbc00296d3b8be6975", null ],
    [ "coarse_over_sampled_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a93ce5e4966999bee9afa2095e8c93944", null ],
    [ "dens_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a6bc0d117614928306779cfce1b691710", null ],
    [ "fine_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#ab737b34de972d90335e0324688543b34", null ],
    [ "fine_over_sampled_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a30bbba8a357f6cbc894793a3fad88548", null ],
    [ "origin_", "classIMP_1_1multifit_1_1AssemblyHeader.html#ad5d3a976a4e0df4afbf310f3d3187f55", null ],
    [ "resolution_", "classIMP_1_1multifit_1_1AssemblyHeader.html#afc0e716bf06065707b6e1e76da3464be", null ],
    [ "spacing_", "classIMP_1_1multifit_1_1AssemblyHeader.html#aad92d2d3ef158a848fa9ba8b77f1bca7", null ],
    [ "threshold_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a4506d37feb055dee769040e68a29d5c1", null ]
];

==> imp-doc-2.1.1.tar.gz: html/classIMP_1_1multifit_1_1AssemblyHeader.js <==
var classIMP_1_1multifit_1_1AssemblyHeader =
[
    [ "AssemblyHeader", "classIMP_1_1multifit_1_1AssemblyHeader.html#aae46c5cee094ac5d24152a4600584ba7", null ],
    [ "get_coarse_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a91052277ec7f86d23d91af1607c48904", null ],
    [ "get_coarse_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a7a19f4aee11a585737fb7ca9cefd68ef", null ],
    [ "get_dens_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a2ff85eef1cb89fdce9d6237de3de70f2", null ],
    [ "get_fine_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a0bfb7859edbd02ffd75ade1c513aa620", null ],
    [ "get_fine_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a662ee4d1263598c0257b0c79a979e641", null ],
    [ "get_origin", "classIMP_1_1multifit_1_1AssemblyHeader.html#a45aa5d7fab318a55bb2e5741573fb771", null ],
    [ "get_resolution", "classIMP_1_1multifit_1_1AssemblyHeader.html#a463328de5a75073c7bd74e08267800df", null ],
    [ "get_spacing", "classIMP_1_1multifit_1_1AssemblyHeader.html#ac65d23eac18ecef255822aa031c0db8b", null ],
    [ "get_threshold", "classIMP_1_1multifit_1_1AssemblyHeader.html#a8f0b4d1085cee5b37fae307242f2e3d2", null ],
    [ "get_type_name", "classIMP_1_1multifit_1_1AssemblyHeader.html#acc6bd5fcda868b5daae5eca73f38c79b", null ],
    [ "get_version_info", "classIMP_1_1multifit_1_1AssemblyHeader.html#a3c5a2eb4e54207a41a1fbd4851710b22", null ],
    [ "set_coarse_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#aaa94d81eebc3c9f584ded58a4616e2cc", null ],
    [ "set_coarse_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#ae1a12a52e48c4055037c120717f8881c", null ],
    [ "set_dens_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a74474ef6f0421a2ec0d17980954bdcc6", null ],
    [ "set_fine_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#af1ace75aa2772da7cec62506bf16df01", null ],
    [ "set_fine_over_sampled_ap_fn", "classIMP_1_1multifit_1_1AssemblyHeader.html#a349d4c07f144d2617ea8f2b79280ea17", null ],
    [ "set_origin", "classIMP_1_1multifit_1_1AssemblyHeader.html#a149d094e7336923ac9fdbc50ed96b826", null ],
    [ "set_resolution", "classIMP_1_1multifit_1_1AssemblyHeader.html#a6461dff6026bbc54f261193059d80e59", null ],
    [ "set_spacing", "classIMP_1_1multifit_1_1AssemblyHeader.html#a3a9378689a931b70abf1672447a6d4ad", null ],
    [ "set_threshold", "classIMP_1_1multifit_1_1AssemblyHeader.html#a421838677fb527d765e2b4af3a081f1f", null ],
    [ "coarse_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#ad29c182851f7b0fbc00296d3b8be6975", null ],
    [ "coarse_over_sampled_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a93ce5e4966999bee9afa2095e8c93944", null ],
    [ "dens_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a6bc0d117614928306779cfce1b691710", null ],
    [ "fine_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#ab737b34de972d90335e0324688543b34", null ],
    [ "fine_over_sampled_ap_fn_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a30bbba8a357f6cbc894793a3fad88548", null ],
    [ "origin_", "classIMP_1_1multifit_1_1AssemblyHeader.html#ad5d3a976a4e0df4afbf310f3d3187f55", null ],
    [ "resolution_", "classIMP_1_1multifit_1_1AssemblyHeader.html#afc0e716bf06065707b6e1e76da3464be", null ],
    [ "spacing_", "classIMP_1_1multifit_1_1AssemblyHeader.html#aad92d2d3ef158a848fa9ba8b77f1bca7", null ],
    [ "threshold_", "classIMP_1_1multifit_1_1AssemblyHeader.html#a4506d37feb055dee769040e68a29d5c1", null ]
];
